@@ -2,7 +2,7 @@
 
 package StaticVolt::Convertor;
 {
-  $StaticVolt::Convertor::VERSION = '0.03';
+  $StaticVolt::Convertor::VERSION = '1.00';
 }
 
 use strict;
@@ -36,7 +36,7 @@ sub register {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -46,7 +46,7 @@ StaticVolt::Convertor - Base class for StaticVolt convertors
 
 =head1 VERSION
 
-version 0.03
+version 1.00
 
 =head1 METHODS
 
@@ -69,18 +69,14 @@ extension.
 
 =head1 AUTHOR
 
-Alan Haggai Alavi <alanhaggai@alanhaggai.org>
+Alan Haggai Alavi <haggai@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Alan Haggai Alavi.
+This software is Copyright (c) 2013 by Alan Haggai Alavi.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
