@@ -2,7 +2,7 @@
 
 package StaticVolt::Convertor::Markdown;
 {
-  $StaticVolt::Convertor::Markdown::VERSION = '0.03';
+  $StaticVolt::Convertor::Markdown::VERSION = '1.00';
 }
 
 use strict;
@@ -21,7 +21,7 @@ __PACKAGE__->register(qw/ markdown md mkd /);
 
 1;
 
-
+__END__
 
 =pod
 
@@ -31,7 +31,7 @@ StaticVolt::Convertor::Markdown - StaticVolt convertor for markdown
 
 =head1 VERSION
 
-version 0.03
+version 1.00
 
 =head1 Registered Extensions
 
@@ -47,18 +47,14 @@ version 0.03
 
 =head1 AUTHOR
 
-Alan Haggai Alavi <alanhaggai@alanhaggai.org>
+Alan Haggai Alavi <haggai@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Alan Haggai Alavi.
+This software is Copyright (c) 2013 by Alan Haggai Alavi.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
